#
# spec file for package linuxptp
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           linuxptp
Version:        3.1.1
Release:        150400.1.11
Summary:        Precision Time Protocol v2 daemon
License:        GPL-2.0-or-later
Group:          Productivity/Networking/Other
URL:            http://linuxptp.sourceforge.net/
Source0:        %{name}-%{version}.tar.xz
Source1:        ptp4l.service
Source2:        sysconfig.ptp4l
Source4:        linuxptp-howto.txt
Source5:        phc2sys.service
Source6:        sysconfig.phc2sys
BuildRequires:  kernel-devel
BuildRequires:  systemd-rpm-macros
Requires(pre):  %fillup_prereq
Provides:       ptp-timekeeping
%{?systemd_requires}

%description
This software is an implementation of the Precision Time Protocol (PTP)
according to the IEEE1588 standard for Linux.

%prep
%setup -q

%build
export EXTRA_CFLAGS="%{optflags} -Iusr/include"
make %{?_smp_mflags}

cp %{SOURCE4} .

%install
make prefix=%{buildroot}%{_prefix} mandir=%{buildroot}/%{_mandir} install

install -Dpm 644 %{SOURCE1} %{buildroot}/%{_unitdir}/ptp4l.service
install -Dpm 644 %{SOURCE5} %{buildroot}/%{_unitdir}/phc2sys.service
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcptp4l
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcphc2sys

install -Dpm 644 configs/default.cfg %{buildroot}/%{_sysconfdir}/ptp4l.conf

install -Dpm 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.ptp4l
install -Dpm 644 %{SOURCE6} %{buildroot}%{_fillupdir}/sysconfig.phc2sys

%pre
%service_add_pre ptp4l.service phc2sys.service

%post
%{fillup_only -n ptp4l}
%{fillup_only -n phc2sys}
%service_add_post ptp4l.service phc2sys.service

%preun
%service_del_preun ptp4l.service phc2sys.service

%postun
%service_del_postun ptp4l.service phc2sys.service

%files
%license COPYING
%doc README.org linuxptp-howto.txt configs
%{_unitdir}/ptp4l.service
%{_unitdir}/phc2sys.service
%{_sbindir}/rcptp4l
%{_sbindir}/rcphc2sys
%config %{_sysconfdir}/ptp4l.conf
%{_sbindir}/hwstamp_ctl
%{_sbindir}/phc2sys
%{_sbindir}/phc_ctl
%{_sbindir}/pmc
%{_sbindir}/ptp4l
%{_sbindir}/nsm
%{_sbindir}/timemaster
%{_sbindir}/ts2phc
%{_mandir}/man8/hwstamp_ctl.8%{?ext_man}
%{_mandir}/man8/nsm.8%{?ext_man}
%{_mandir}/man8/phc2sys.8%{?ext_man}
%{_mandir}/man8/phc_ctl.8%{?ext_man}
%{_mandir}/man8/pmc.8%{?ext_man}
%{_mandir}/man8/ptp4l.8%{?ext_man}
%{_mandir}/man8/timemaster.8%{?ext_man}
%{_mandir}/man8/ts2phc.8%{?ext_man}
%{_fillupdir}/sysconfig.ptp4l
%{_fillupdir}/sysconfig.phc2sys

%changelog
* Tue Jul  6 2021 jbohac@suse.com
- Update to version 3.1.1:
  * Version 3.1.1
  * tc: Fix length of follow-up message of one-step sync.
  * Validate the messageLength field of incoming messages.
* Tue Nov 10 2020 jbohac@suse.com
- Update to version 3.1:
  * ts2phc: nmea: Drop time of day readings older than five seconds.
  * ts2phc: nmea: Update the leap seconds table on demand.
  * ts2phc: nmea: Add a configuration option for the current leap seconds file.
  * ts2phc: nmea: Add error messages for leap second lookup failures.
  * ts2phc: nmea: Correct UTC to TAI conversion.
  * posix_clock_open: derive PHC index from device name if possible
  * phc_ctl: display all capability information
  * ts2phc: Ignore pulses with invalid time stamps.
  * ts2phc: Fix memory leak.
  * ts2phc: Use proper close method on the error path.
  * port: Support slave event monitoring of delay timing data.
  * monitor: Add support for slave delay timing data TLV.
  * pmc: Show slave receive timing data TLVs attached to signaling messages.
  * port: Support slave event monitoring of Sync timing data.
  * clock: Create a slave event monitor.
  * Introduce a module for slave event monitoring.
  * Reject path trace TLVs with excessive elements.
  * Let the free running port state reflect the synchronization uncertain flag.
  * pmc: Support getting and setting the local synchronization uncertain flag.
  * Implement the synchronization uncertain flag.
  * Add support for write phase mode.
  * Decouple servo state from automotive profile.
  * ts2phc: Support using a GPS radio as the master clock.
  * Introduce a leap second table.
  * ts2phc: Support using a PHC as the master clock.
  * Introduce the ts2phc program.
  * pmc: Allow multiple local subscribers.
  * pmc: Subscribe to port state push notification events when requested.
  * clock: reset master/local rr when best clock id changes
  * unicast: Enable sharing master tables between ports.
  * Accept external PHC devices from the command line.
  * phc2sys: Fix frequency estimation when synchronizing a PHC to the system clock.
  * Correct the signature of the legacy system offset measurement method.
  * ptp4l: Add configuration option for socket priority
  * sk: Recognize HWTSTAMP_FILTER_SOME
  * Improve G.8275.[12] example configs.
  * rtnl: add team activebackup support
  * Ignore signaling messages on target port mismatch.
  * Avoid fault when receiving zero length packets
  * phc2sys: Fix crash when trying to synchronize unadjustable clock.
  * Added support for opening POSIX clock devices
  * Allow ignoring source port identity in end to end mode.
  * port: correction of port name used port_open
  * Add example configuration for Automotive Profile.
  * Add ignore_source_id config option.
  * Add inhibit_announce config option.
  * Add BMCA config option.
  * port: Add configurable option to set asCapable.
  * timemaster: Allow ptp4l-specific sections in [ptp4l.conf].
  * unicast: Process timeouts equal to current time.
  * snmp4lptp: added snmp4lptp.8
  * Add possibility to set clockIdentity
  * Introduce the maxStepsRemoved attribute
  * config: Add hardware time stamp filter setting mode
  * snmp4lptp: Added function for data collection from ptp4l program.
  * snmp4lptp: Added communication to ptp4l via the UDS port.
  * snmp4lptp: Add snmp sub agent for linuxptp
- re-introduce the _service file
* Wed Jul 24 2019 matthias.gerstner@suse.com
- removal of SuSEfirewall2 service, since SuSEfirewall2 has been replaced by
  firewalld, see [1].
  [1]: https://lists.opensuse.org/opensuse-factory/2019-01/msg00490.html
* Mon Nov 26 2018 mpluskal@suse.com
- Update to stable release 2.0:
  * Peer-to-Peer Transparent Clock support
  * End-to-End Transparent Clock support
  * Unicast support
  * Support for all three Telecom Profiles
    + T-REC-G.8265.1-201407
    + T-REC-G.8275.1-201606
    + T-REC-G.8275.2-201708
- Changes for version 1.9.2:
  * Fixed stack buffer overflow in the new NetSync Monitor code (since 1.9)
  * Command line support for every configuration variable via long options
  * IPoIB interface support
  * Improved Delay Request performance at high message rates
  * Improved UTC offset tracking
  * Multiple TLV support
  * NetSync Monitor protocol support
  * Peer to peer one-step
  * Support for bonded interfaces
- No longer use _service
* Tue Apr  3 2018 jbohac@suse.com
  Update to version 1.9+git1.gd14f11f:
  * Expand and rationalize time stamping options.
  * Introduce peer to peer one step.
  * pmc: add long options and configuration file
  * port: Implement the NetSync Monitor protocol.
  * Introduce an option to ignore the transport specific field.
  * clock: add option to specify initial path delay.
  * sk: turn warnings about unexpected RX filter into debug messages.
* Thu Feb  8 2018 jbohac@suse.com
- change the versioning scheme, resulting in version
  1.8+git65.g303b08c
* Thu Feb  8 2018 mpluskal@suse.com
- Update to version v1.8+git.20180101 (bsc#1050682):
  * clock: Don't forward management requests to UDS port.
  * Add an acknowledgment in the readme for Meinberg.
  * phc2sys: update '-s' option
  * sk: don't leak socket when reading of IB GUID fails.
  * Add compile time sanity check for interface name lengths.
  * phc_ctl: fix adj command to accept negative offset.
  * port: return timestamping iface in port properties
  * phc2sys: re-create clock clkid and servo when phc index changed
  * phc2sys: split servo_add from function clock_add
  * transport: pass struct interface to transport_open
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Mon Jul 10 2017 jengelh@inai.de
- Remove future goals from description.
* Fri Jun 30 2017 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Use url for source
- Use kernel-devel instead full source
* Thu May 25 2017 lpechacek@suse.com
- upgraded to 1.8
- new tools: timemaster, phc_ctl
* Tue Sep  2 2014 ro@suse.de
- sanitize release line in specfile
* Thu Mar 27 2014 lpechacek@suse.com
- updated How To to mention ethtool (bnc#865358)
* Wed Mar 26 2014 jbohac@suse.cz
- convert to systemd (bnc#865355)
  - two separate services (ptp4l and phc2sys) instead of linuxptp
  - two separate config files:
    /etc/syscconfig/ptp4l and /etc/sysconfig/phc2sys instead of
    /etc/sysconfig/linuxptp
* Tue Feb 18 2014 jbohac@suse.cz
- upgraded to 1.4
- fixed FSF address in init file
* Fri Jul 26 2013 lpechacek@suse.com
- added Linux PTP Howto
* Thu Jun  6 2013 lpechacek@suse.com
- adjusted sysconfig defaults to match changes made to phc2sys
  behavior
* Wed Jun  5 2013 jbohac@suse.cz
- upgraded to 1.2.git74e70372
* Tue Apr 23 2013 jbohac@suse.cz
- upgraded to 1.2
* Mon Mar 25 2013 lpechacek@suse.com
- reviewed by Security (bnc#809336)
* Fri Mar 15 2013 cfarrell@suse.com
- license update: GPL-2.0+
  No indication of a GPL version 2 only license. Also, use SPDX format
  where possible
* Wed Mar  6 2013 lpechacek@suse.com
- upgraded to 1.1
* Fri Feb 15 2013 lpechacek@suse.com
- initial packaging
